@@ -1,27 +1,39 @@
-/*  $Id: getaddrinfo.h 9768 2014-12-07 21:22:57Z iulius $
-**
-**  Replacement implementation of getaddrinfo.
-**
-**  Written by Russ Allbery <eagle@eyrie.org>
-**  This work is hereby placed in the public domain by its author.
-**
-**  This is an implementation of the getaddrinfo family of functions for
-**  systems that lack it, so that code can use getaddrinfo always.  It
-**  provides IPv4 support only; for IPv6 support, a native getaddrinfo
-**  implemenation is required.
-**
-**  This file should generally be included by way of portable/socket.h rather
-**  than directly.
-*/
+/* $Id: getaddrinfo.h 10099 2016-11-04 22:21:59Z iulius $
+ *
+ * Replacement implementation of getaddrinfo.
+ *
+ * This is an implementation of the getaddrinfo family of functions for
+ * systems that lack it, so that code can use getaddrinfo always.  It provides
+ * IPv4 support only; for IPv6 support, a native getaddrinfo implemenation is
+ * required.
+ *
+ * This file should generally be included by way of portable/socket.h rather
+ * than directly.
+ *
+ * The canonical version of this file is maintained in the rra-c-util package,
+ * which can be found at <https://www.eyrie.org/~eagle/software/rra-c-util/>.
+ *
+ * Written by Russ Allbery <eagle@eyrie.org>
+ *
+ * The authors hereby relinquish any claim to any copyright that they may have
+ * in this work, whether granted under contract or by operation of law or
+ * international treaty, and hereby commit to the public, at large, that they
+ * shall not, at any time in the future, seek to enforce any copyright in this
+ * work against any person or entity, or prevent any person or entity from
+ * copying, publishing, distributing or creating derivative works of this
+ * work.
+ */
 
 #ifndef PORTABLE_GETADDRINFO_H
 #define PORTABLE_GETADDRINFO_H 1
 
 #include "config.h"
+#include "portable/macros.h"
 
 /* Skip this entire file if a system getaddrinfo was detected. */
-#if !HAVE_GETADDRINFO
+#ifndef HAVE_GETADDRINFO
 
+/* OpenBSD likes to have sys/types.h included before sys/socket.h. */
 #include <sys/types.h>
 #include <sys/socket.h>
 
