@@ -1,4 +1,4 @@
-/*  $Id: icd.c 8190 2008-11-23 21:42:32Z iulius $
+/*  $Id: icd.c 9659 2014-08-30 08:08:11Z iulius $
 **
 **  Routines to read and write the active file.
 */
@@ -8,6 +8,7 @@
 #include "portable/mmap.h"
 #include <sys/uio.h>
 
+#include "inn/fdflag.h"
 #include "inn/innconf.h"
 #include "inn/mmap.h"
 #include "innd.h"
@@ -108,7 +109,7 @@ ICDwrite(void)
     HISsync(History);
     SMflushcacheddata(SM_ALL);
 
-    if (ICDactivedirty) {
+    if (ICDactivedirty != 0) {
 	ICDwriteactive();
 	ICDactivedirty = 0;
     }
@@ -439,8 +440,7 @@ ICDrmgroup(NEWSGROUP *ngp)
 **  Open the active file and "map" it into memory.
 */
 char *
-ICDreadactive(endp)
-    char		**endp;
+ICDreadactive(char **endp)
 {
     struct stat		Sb;
 
@@ -454,7 +454,7 @@ ICDreadactive(endp)
 	syslog(L_FATAL, "%s cant open %s %m", LogName, ICDactpath);
 	exit(1);
     }
-    close_on_exec(ICDactfd, true);
+    fdflag_close_exec(ICDactfd, true);
 
 #ifdef HAVE_MMAP
 
