@@ -1,4 +1,4 @@
-/*  $Id: conffile.c,v 1.22 2003/01/19 01:15:33 rra Exp $
+/*  $Id: conffile.c 10012 2016-05-05 12:41:10Z iulius $
 **
 **  Routines for reading in incoming.conf-style config files.
 */
@@ -6,7 +6,7 @@
 #include "config.h"
 #include "clibrary.h"
 #include "conffile.h"
-#include "libinn.h"
+#include "inn/libinn.h"
 
 static int getconfline(CONFFILE *F, char *buffer, int length) {
   if (F->f) {
@@ -18,7 +18,7 @@ static int getconfline(CONFFILE *F, char *buffer, int length) {
     strlcpy(buffer, F->array[F->lineno], F->sbuf);
   }
   F->lineno++;
-  if (strlen (F->buf) == F->sbuf) {
+  if (strlen (F->buf) >= F->sbuf - 1) {
     return 1; /* Line too long */
   } else {
     return 0;
@@ -41,7 +41,7 @@ static char *CONFgetword(CONFFILE *F)
   char *s;
   char *t;
   char *word;
-  bool flag;
+  bool comment;
 
   if (!F) return (NULL);	/* No conf file */
   if (!F->buf || !F->buf[0]) {
@@ -57,28 +57,26 @@ static char *CONFgetword(CONFFILE *F)
      /* Ignore blank and comment lines. */
      if ((p = strchr(F->buf, '\n')) != NULL)
        *p = '\0';
-     if ((p = strchr(F->buf, '#')) != NULL) {
-       if (p == F->buf || (p > F->buf && *(p - 1) != '\\'))
-           *p = '\0';
-     }
      for (p = F->buf; *p == ' ' || *p == '\t' ; p++);
-     flag = true;
-     if (*p == '\0' && !cfeof(F)) {
-       flag = false;
+     if ((*p == '\0' || *p == '#') && !cfeof(F)) {
        if (getconfline(F, F->buf, F->sbuf))
          return (NULL); /* Line too long */
        continue;
      }
      break;
-  } while (!cfeof(F) || !flag);
+  } while (!cfeof(F));
 
+  comment = false;
   if (*p == '"') { /* double quoted string ? */
     p++;
     do {
-      for (t = p; (*t != '"' || (*t == '"' && *(t - 1) == '\\')) &&
+      for (t = p; (*t != '"' || *(t - 1) == '\\') &&
              *t != '\0'; t++);
       if (*t == '\0') {
+        if (strlen(F->buf) >= F->sbuf - 2)
+          return (NULL); /* Line too long */
         *t++ = '\n';
+        *t = '\0';
         if (getconfline(F, t, F->sbuf - strlen(F->buf)))
           return (NULL); /* Line too long */
         if ((s = strchr(t, '\n')) != NULL)
@@ -87,23 +85,31 @@ static char *CONFgetword(CONFFILE *F)
       else 
         break;
     } while (!cfeof(F));
+    if (*t != '"')
+      return (NULL);
     *t++ = '\0';
   }
   else {
-    for (t = p; *t != ' ' && *t != '\t' && *t != '\0'; t++);
+    for (t = p; *t != ' ' && *t != '\t' && *t != '\0'; t++)
+      if (*t == '#' && (t == p || *(t - 1) != '\\')) {
+        comment = true;
+        break;
+      }
     if (*t != '\0')
       *t++ = '\0';
   }
   if (*p == '\0' && cfeof(F)) return (NULL);
   word = xstrdup (p);
-  for (p = F->buf; *t != '\0'; t++)
-    *p++ = *t;
+  p = F->buf;
+  if (!comment)
+    for (; *t != '\0'; t++)
+      *p++ = *t;
   *p = '\0';
 
   return (word);
 }
 
-CONFFILE *CONFfopen(char *filename)
+CONFFILE *CONFfopen(const char *filename)
 {
   FILE *f;
   CONFFILE *ret;
